@@ -9,8 +9,12 @@ import jsii.compat
 import publication
 
 import aws_cdk.aws_applicationautoscaling
+import aws_cdk.aws_cloudformation
+import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_iam
+import aws_cdk.aws_lambda
 import aws_cdk.core
+import aws_cdk.custom_resources
 __all__ = []
 
 publication.publish()
